veloxml.linear package
======================

Submodules
----------

veloxml.linear.elasticnet\_regression module
--------------------------------------------

.. automodule:: veloxml.linear.elasticnet_regression
   :members:
   :show-inheritance:
   :undoc-members:

veloxml.linear.lasso\_regression module
---------------------------------------

.. automodule:: veloxml.linear.lasso_regression
   :members:
   :show-inheritance:
   :undoc-members:

veloxml.linear.linear\_regression module
----------------------------------------

.. automodule:: veloxml.linear.linear_regression
   :members:
   :show-inheritance:
   :undoc-members:

veloxml.linear.logistic\_regression module
------------------------------------------

.. automodule:: veloxml.linear.logistic_regression
   :members:
   :show-inheritance:
   :undoc-members:

veloxml.linear.ridge\_regression module
---------------------------------------

.. automodule:: veloxml.linear.ridge_regression
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: veloxml.linear
   :members:
   :show-inheritance:
   :undoc-members:
